#restart_widget {
    position:fixed;
    bottom:0px;
    right:10px;
    border: 1px solid #DDDDDD;
    padding:10px;
    border-radius: 3px;
    box-shadow: 0 0 2px #FFFFFF inset;
    background: none repeat scroll 0 0 rgba(255, 255, 255, 0.95);
    max-width:300px;
}

#restart_widget h1 {
    margin-top:0px;
    margin-left:0px;
}

#restart_widget #toggle {
    position:absolute;
    top:5px;
    right:5px;
}